import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import japanize_matplotlib
from scipy.cluster.hierarchy import linkage
from scipy.cluster.hierarchy import dendrogram

#   ExcelファイルをPandasのDataFrame型として読み込む
fl_nm = 'rain.xlsx' 
with pd.ExcelFile(fl_nm) as xlfile:
    df = pd.read_excel(xlfile)

cities = df.values[:,0]
data_v = np.array(df.values[:,1:], dtype=float)
#
#        Ward法によるクラスタリング
#
row_clusters = linkage(data_v, method = 'ward')
fig = plt.figure(figsize = (7, 7)) 
row_dendr = dendrogram(row_clusters, labels = cities,
                       orientation = 'right', leaf_font_size = 10)
plt.title('Clustering by Ward method', fontsize=14)
plt.tight_layout()
plt.savefig('FigClusterWard.png')
plt.show()
#
#         都市間の非類似度
#
n = len(cities)
dists = np.empty((n,n))
for i in range(n):
    for j in range(n):
        dists[i][j] = np.sum(np.abs(data_v[i] - data_v[j]))
print('dists =\n', dists)
#
#           Complete法によるクラスタリング
#
row_clusters = linkage(dists, method = 'complete')
fig = plt.figure(figsize = (7, 7), facecolor = 'white')
row_dendr = dendrogram(row_clusters, labels = cities,
                       orientation = 'right', leaf_font_size = 10)
plt.title('Clustering by Complete method', fontsize = 14)
plt.tight_layout()
plt.savefig('FigClusterComplete.png')
plt.show()

